///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2006-2014 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		GF	Jul 19, 2006	Created
//		TF	Mar 10, 2014	XML and graph database creation 
//
///////////////////////////////////////////////////////////////////////////////
package com.tietoenator.trip.jxp.examples.database;

import com.tietoenator.trip.jxp.TdbMessageProvider;
import com.tietoenator.trip.jxp.TdbTripFeature;
import com.tietoenator.trip.jxp.database.TdbDatabaseDesign;
import com.tietoenator.trip.jxp.database.TdbFieldDesign;
import com.tietoenator.trip.jxp.examples.util.Console;
import com.tietoenator.trip.jxp.examples.util.SessionFactory;
import com.tietoenator.trip.jxp.session.TdbSession;

/**
 * Simple example showing how to create a new database design, add fields
 * to the design, etc.
 */
public class Create
{
   // Show any success message that might be forthcoming from the server

   private static void showMessages(TdbMessageProvider prv)
   {
      for (String msg : prv.messageList())
      {
         System.out.println(msg);
      }
      prv.resetMessages();
   }

   /**
    * Main entry point
    * @param args Not used
    */
   public static void main(String[] args)
   {
      try
      {
         TdbSession session = SessionFactory.newInstance("**** Create Database ****", false);
         TdbDatabaseDesign db = new TdbDatabaseDesign(session);
         TdbFieldDesign field;
         Console stdin = new Console();
         boolean added = false;
         String dbname, location, fldname, fldtype, encinitkey;

         dbname = stdin.readln("Database Name", "");
         if (dbname.length() == 0)
         {
            return;
         }
         location = stdin.readln("File location (logical name)", "");
         if (location.length() == 0)
         {
            return;
         }

         // Set the file locations
         db.setBafFile(location + ":" + dbname + ".BAF");
         db.setBifFile(location + ":" + dbname + ".BIF");
         db.setVifFile(location + ":" + dbname + ".VIF");
         
         if (stdin.readbool("Create XML database?",false,true))
         {
             db.setXmlEnabled(true);
         }
         else if (session.supportsFeature(TdbTripFeature.GraphDatabases) && 
                  stdin.readbool("Create graph database?",false,true))
         {
             db.setGraph(true);
         }
 
         // Unicode databases are best practise
         db.setCharacterSet("UTF");
         
         // Store the initial database design on the server -- this serves
         // to validate the availability of the database name, and the user's
         // ability to actually create database designs before spending time
         // defining fields, etc. Note that there's no requirement to do this
         // as a separate step, however. Applications could choose to add the
         // field collection to the design before storing for the first time.
         db.put(dbname);
         showMessages(db);

         // Prompt for field names / types to create (very simple) field collection
         for (;;)
         {
            fldname = stdin.readln("Field name (blank to finish)", "");
            if (fldname.length() == 0)
            {
               break;
            }
            fldtype = stdin.readln("Field type", "");
            if (fldtype.length() == 0)
            {
               break;
            }

            // Add a new field to the fields collection
            field = new TdbFieldDesign();
            field.setName(fldname);
            field.setType(fldtype);
            db.addField(field);
            added = true;
         }

         // If we added any fields, store the database design again; nothing that
         // we've done to the fields collection is committed to the server until
         // we put the design. Until that point, all interaction is local only.
         if (added)
         {
            db.put(dbname);
            showMessages(db);
         }

         // Terminate the session
         session.logout();
      }
      catch (Exception e)
      {
         e.printStackTrace();
      }
   }
}
