///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2010 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		TF	Jan 05, 2010	Created
//
///////////////////////////////////////////////////////////////////////////////
package com.tietoenator.trip.jxp.examples.database;

import com.tietoenator.trip.jxp.database.TdbDatabaseDesign;
import com.tietoenator.trip.jxp.database.TdbFieldDesign;
import com.tietoenator.trip.jxp.examples.util.Console;
import com.tietoenator.trip.jxp.examples.util.SessionFactory;
import com.tietoenator.trip.jxp.session.TdbDateform;
import com.tietoenator.trip.jxp.session.TdbSession;

/**
 * Simple example showing how to retrieve a database design.
 */
public class ShowDesign
{
    private static void printPadding(int size)
    {
        for (int i=0;i<size;i++)
            System.out.print(" ");
    }

    private static void printRightPadded(String str, int size)
    {
        System.out.print(str);
        printPadding(size - str.length());
    }

    private static void printLeftPadded(String str, int size)
    {
        printPadding(size - str.length());
        System.out.print(str);
    }

    /**
     * Main entry point
     * @param args Not used
     */
    public static void main(String[] args)
    {
        try
        {
            TdbSession session = SessionFactory.newInstance("**** Show Database ****", false);
            TdbDatabaseDesign db = new TdbDatabaseDesign(session);
            Console stdin = new Console();
            String dbname;

            dbname = stdin.readln("Database Name", "");
            if (dbname.length() == 0)
            {
                return;
            }

            db.get(dbname);

            // The current TRIP dateform
            TdbDateform df = session.getCurrentDateform();

            // Display some statistics about the database, using the TdbDateform
            // object to format dates
            System.out.println();
            System.out.println("Data base:     " + db.getName().toUpperCase());
            System.out.println("Owner:         " + db.getOwnerName().toUpperCase());
            System.out.println("XML Enabled:   " + (db.isXmlEnabled() ? "Yes" : "No"));
            System.out.println("Record count:  " + db.getRecordCount());

            System.out.println("Last updated:  " + ((db.getLastUpdate().length()>0) ? df.formatTimestamp(db.getLastUpdate()) : "n/a"));
            System.out.println("Last indexed:  " + ((db.getLastIndex().length()>0) ? df.formatTimestamp(db.getLastIndex()) : "n/a"));
            
            System.out.println("Language:      "  + db.getLanguage());
            System.out.println("Character set: "  + db.getCharacterSet());
            System.out.println("Folding class: "  + db.getFoldingClass());

            // Display a few details about the fields.
            System.out.println();
            System.out.println("Field Nr Field Name          Field Type          Indexed");
            System.out.println("-------- ------------------- ------------------- -------");
            for (TdbFieldDesign fd : db.fields())
            {
                printLeftPadded(Integer.toString(fd.getNumber()),5);
                printPadding(4);
                printRightPadded(fd.getName(),20);
                printRightPadded(fd.getType(),20);
                System.out.print(fd.isIndexed() ? "Yes" : "No");
                System.out.println();
            }

            // Terminate the session
            session.logout();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
    }
}
