///////////////////////////////////////////////////////////////////////////////
//
// TRIPjxp Programming Examples
//
// Copyright (C) 2006-2009 Tieto Sweden AB - All Rights Reserved
//
///////////////////////////////////////////////////////////////////////////////
//
// Modification History:
//		GF	Mar 29, 2006	Created
//
///////////////////////////////////////////////////////////////////////////////
package com.tietoenator.trip.jxp.examples.util;

/**
 * Utility class to construct tabular string formats
 */
public class StringFormatter
{

   private StringBuffer m_sb;
   private String m_spaces = "                                                                        ";

   /**
    * Constructor
    */
   public StringFormatter()
   {
      m_sb = new StringBuffer();
   }

   /**
    * Add a string with no length requirements
    * @param s The string
    */
   public void add(String s)
   {
      m_sb.append(s);
   }

   /**
    * Add an integer
    * @param i The integer
    */
   public void add(int i)
   {
      m_sb.append(i);
   }

   /**
    * Add an integer, padding to the provided size if the integer's string
    * length is too small
    *
    * @param i Integer to add
    * @param sz Minimum size to pad
    */
   public void add(int i, int sz)
   {
      StringBuffer sb = new StringBuffer();
      sb.append(i);
      if (sb.length() < sz)
      {
         m_sb.append(sb);
         m_sb.append(m_spaces.substring(0, sz - sb.length()));
      }
   }

   /**
    * Add a right-justified integer, padding as necessary
    * @param i Integer to add
    * @param sz Minimum size to pad
    */
   public void addRight(int i, int sz)
   {
      StringBuffer sb = new StringBuffer();
      sb.append(i);
      if (sb.length() < sz)
      {
         m_sb.append(m_spaces.substring(0, sz - sb.length()));
         m_sb.append(sb);
      }
   }

   /**
    * Add a string, either truncating or padding as required
    * @param s String to add
    * @param sz Size of column
    */
   public void add(String s, int sz)
   {
      int slen = s.length();
      if (slen > sz)
      {
         m_sb.append(s.substring(0, sz));
      }
      else
      {
         m_sb.append(s).append(m_spaces.substring(0, sz - slen));
      }
   }

   /**
    * Add a right-justified string, truncating or padding as required
    * @param s String to add
    * @param sz Size of column
    */
   public void addRight(String s, int sz)
   {
      int slen = s.length();
      if (slen > sz)
      {
         m_sb.append(s.substring(0, sz));
      }
      else
      {
         m_sb.append(m_spaces.substring(0, sz - slen)).append(s);
      }
   }

   /**
    * Reset
    */
   public void clear()
   {
      m_sb = new StringBuffer();
   }

   /**
    * Get the formatted string
    * @return The string
    */
   public String toString()
   {
      return m_sb.toString();
   }
}
